Enum twilight_gateway::error::ProcessErrorType
source · pub enum ProcessErrorType {
Deserializing {
event: String,
},
SendingMessage,
}Expand description
Type of ProcessError that occurred.
Variants
Deserializing
Fields

event: StringGateway event.
Unlike ReceiveMessageErrorType::Deserializing, the event is
never modified.
Gateway event could not be deserialized.
SendingMessage
Message could not be sent over the Websocket connection.
This may happen when the shard sends heartbeats or attempts to identify a new gateway session.