Struct twilight_gateway::error::ReceiveMessageError
source · pub struct ReceiveMessageError { /* private fields */ }Expand description
Receiving the next Websocket message failed.
Implementations
sourceimpl ReceiveMessageError
impl ReceiveMessageError
sourcepub const fn is_fatal(&self) -> bool
pub const fn is_fatal(&self) -> bool
Whether the error is fatal.
If the error is fatal then further attempts to use the shard will return more fatal errors.
sourcepub const fn kind(&self) -> &ReceiveMessageErrorType
pub const fn kind(&self) -> &ReceiveMessageErrorType
Immutable reference to the type of error that occurred.
sourcepub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>>
pub fn into_source(self) -> Option<Box<dyn Error + Send + Sync>>
Consume the error, returning the source error if there is any.
sourcepub fn into_parts(
self
) -> (ReceiveMessageErrorType, Option<Box<dyn Error + Send + Sync>>)
pub fn into_parts(
self
) -> (ReceiveMessageErrorType, Option<Box<dyn Error + Send + Sync>>)
Consume the error, returning the owned error type and the source error.